# mypy-boto3-clouddirectory

Mypy-friendly auto-generated type annotations for `boto3 clouddirectory 1.10.39` service.
More information can be found [here](https://github.com/vemel/mypy_boto3).

- [mypy-boto3-clouddirectory](#mypy-boto3-clouddirectory)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
    - [Code auto-complete](#code-auto-complete)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `clouddirectory` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-clouddirectory]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking.

```python
import boto3

from mypy_boto3 import clouddirectory
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_clouddirectory as clouddirectory

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("clouddirectory")
client: clouddirectory.CloudDirectoryClient = boto3.client("clouddirectory")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: clouddirectory.CloudDirectoryClient = session.client("clouddirectory")


# Paginators need type annotation on creation
list_applied_schema_arns_paginator: clouddirectory.ListAppliedSchemaArnsPaginator = client.get_paginator("list_applied_schema_arns")
list_attached_indices_paginator: clouddirectory.ListAttachedIndicesPaginator = client.get_paginator("list_attached_indices")
list_development_schema_arns_paginator: clouddirectory.ListDevelopmentSchemaArnsPaginator = client.get_paginator("list_development_schema_arns")
list_directories_paginator: clouddirectory.ListDirectoriesPaginator = client.get_paginator("list_directories")
list_facet_attributes_paginator: clouddirectory.ListFacetAttributesPaginator = client.get_paginator("list_facet_attributes")
list_facet_names_paginator: clouddirectory.ListFacetNamesPaginator = client.get_paginator("list_facet_names")
list_incoming_typed_links_paginator: clouddirectory.ListIncomingTypedLinksPaginator = client.get_paginator("list_incoming_typed_links")
list_index_paginator: clouddirectory.ListIndexPaginator = client.get_paginator("list_index")
list_managed_schema_arns_paginator: clouddirectory.ListManagedSchemaArnsPaginator = client.get_paginator("list_managed_schema_arns")
list_object_attributes_paginator: clouddirectory.ListObjectAttributesPaginator = client.get_paginator("list_object_attributes")
list_object_parent_paths_paginator: clouddirectory.ListObjectParentPathsPaginator = client.get_paginator("list_object_parent_paths")
list_object_policies_paginator: clouddirectory.ListObjectPoliciesPaginator = client.get_paginator("list_object_policies")
list_outgoing_typed_links_paginator: clouddirectory.ListOutgoingTypedLinksPaginator = client.get_paginator("list_outgoing_typed_links")
list_policy_attachments_paginator: clouddirectory.ListPolicyAttachmentsPaginator = client.get_paginator("list_policy_attachments")
list_published_schema_arns_paginator: clouddirectory.ListPublishedSchemaArnsPaginator = client.get_paginator("list_published_schema_arns")
list_tags_for_resource_paginator: clouddirectory.ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
list_typed_link_facet_attributes_paginator: clouddirectory.ListTypedLinkFacetAttributesPaginator = client.get_paginator("list_typed_link_facet_attributes")
list_typed_link_facet_names_paginator: clouddirectory.ListTypedLinkFacetNamesPaginator = client.get_paginator("list_typed_link_facet_names")
lookup_policy_paginator: clouddirectory.LookupPolicyPaginator = client.get_paginator("lookup_policy")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- Latest version of `boto3` is used.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from latest documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Code is processed by [black](https://github.com/psf/black) for readability.